# RED-I Authors

The RED-I Project would not be possible without the generous contributions of
our authors and contributors.

David R Nelson and his HCV Target project and the University of Florida
Clinical Translational Science Institute for providing the seed funding
that launched the RED-I Project.

Christopher P. Barnes (senrabc@gmail.com) provided the original concept and
proposal for a generic, open source, standards-based bridge between the
electronic medical record and REDCap systems.

Many thanks to David Nelson, Mike Freid, Joy Peter, Ken Berguist, and
Monika Vainorius of the HCV Target Study Team and all of the HCV Target study
sites for being the pilot project for RED-I.  You all helped make it great.

Thanks also to Linc Moldawer, Jen Lanz, Ruth Davis, and Scott Brakenridge of
the UF Surgery Genomics for being our second implementation site.
Diversity makes  us stronger.

Philip Chase (philipbchase@gmail.com), Nicholas Rejack (nrejack@ufl.edu),
Erik Schmidt, and Chris Barnes provided direction to the development effort.

Radha Kandula, Mohan Das Katragadda, Ruchi Desai, Yang Li, Kumar Sadhu,
Alex Loiacono, Erik Schmidt, Nicholas Rejack, Philip Chase, Roy Keyes,
Andrei Sura, and Taeber Rapczak provided code to make this project awesome.
We are nothing without our developers.
